/*
Programmer: Timothy McNeel / William Waldron
This program creates a SAS transport file of the HINTS 2005 Complete and Partial
Extended records combined.

The following modifications were made for the
November 15 2005 release:
-Corrected value 22 to 23 for ca13whatlookcancerinfo1-ca13whatlookcancerinfo6
-Corrected value 52 to 6 for HS05FreqGoProvider
-Corrected label of GA2WhereUseInternet2 (capitalization)
-Corrected label of MM05iCheckEarlyDetectC (removed extra space)
-Corrected label of MM04ReduceCancerS_OS (removed extra space)
-Corrected label of EB17ChangeBehaviorExer (removed extra space)
-Removed groupings of values for several formats
-Corrected format $EXTRSLT (changed label for ML, added label for LM)
-Corrected format SPAGE (97, 98, 99 changed to 997, 998, 999)
-Corrected format PC05PROV (added label for 9)
-Corrected format PC06QUES (added labels for 8 and 9)
-Corrected format CV06WHEN (97 removed; 98 and 99 changed to 8 and 9)
-Corrected format CV07HOWO (97 removed; 98 and 99 changed to 8 and 9)
-Corrected format MM06SYMF (spelling)
-Corrected format SP01BSHA (97, 98, 99 changed to 7, 8, 9)
-Corrected format TU21NOWU (capitalization)
-Corrected format EB01FRUF (added label for 4)
-Corrected format SN06RELI (added labels for 8 and 9)
-Corrected format DM02MARI (capitalization)
-Corrected format DM03EDUC (spelling)
-Corrected format DM05RACE (values were off by one)
-Corrected format DB10WHER (all values were incorrect)
-Corrected format DB11WHYC (added labels for 97 and 99)

The following modifications were made for the
January 10, 2006 release:
-Added Recode AgeGrp		- 4 Levels (18-34 , 35-39, 40-45, 45+)
-Added Recode Educ4 	- 4 Levels ( <HS, =HS, <CG, =CG)
-Added Recode Education5 	- 5 Levels (<HS, =HS, <BS/BA, =BS/BA , >BS/BA )
-Added Recode HHIncB  		- 5 Levels ( <25K ,  25 to <35, 35 to < 50, 50 to <75, 75+ ).
-Added Recode HHIncA    	-10 Levels (<10k,10-<15,15-<20,20-<25,25-<35,35-<50,50-<75,75-<100,100-< 200,200+)
-Added Recode RaceEthn 		- 7 levels (Hispanic,NH White,NH Black or AA,NH AI/AN,NH Asian,NH NH/PI,NH Multiple Races)
-Added Recode Pap3Yr 		- 3 Levels ( <=3yrs, >3yrs, never ).
-Added Recode Psa1yr 		- 3 Levels ( <= 1yr, >1 yr, never ).
-Added Recode Mam1Yr 		- 3 Levels ( <= 1yr, >1 yr, never ).
-Added Recode FOB1Yr 		- 3 Levels ( <= 1yr, >1 yr, never ).
-Added Recode End5yr 		- 3 Levels ( <=5yrs, >5yrs, never ).
-Added Recode Fruits 	  	- Continuous - How many times a day do you eat fruits?
-Added Recode Vegetables 	- Continuous - How many times a day do you eat vegetables?
-Added Recode FruitJuice	- Continuous - How many times a day do you drink fruit juice?
-Added Recode Potatoes		- Continuous - How many times a day do you eat potatoes?
-Added Recode MM04count 	- Recode to count MM04ReduceCancer Responses
-Added Recode MM06count 	- Recode to count MM06SymptomsOfCancer Responses
-Added Recode MM01ChanceGetCancer		   - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM02RelativeChanceCancer     - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM03FreqWorryCancer          - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05aCannotLowerChance       - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05bTooManyRecommendations  - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05cCancerOverYears         - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05dSlowDownCancer          - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05eBehaviorCauseCancer     - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05fEverythingCausesCancer  - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05hCheckCancerAfraid       - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05iCheckEarlyDetect        - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM05LPainPriorToDx           - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added Recode MM07HowManySurvive           - Combines Values from all MM Groups (Lung, Colon, Skin)
-Added 2003 rural-urban continuum codes from http://www.ers.usda.gov/briefing/rurality/RuralUrbCon/
-Added Designated Metro Area
-Added Region
-Added Census Division
-Added Recode Psychological Distress
-Added Recode CancerType (Michael Osswald provided interpretation)
-Added Recode Age at Cancer Diagnosis
-Added Recode BMI ( Continuous )
-Added Recode Time Since Cancer Diagnosis ( <=1 yr, 2-5 yrs, 6-10 yrs, 11+ yrs )
-Added Region ( Northeast, Midwest, West, South )

The following changes were made for the
February 1, 2006 release

-Edited labels for Mam1Yr FOB1Yr End5yr Psa1yr Pap1yr to reference US Preventive Services Task Force
-Recoded Mam1Yr - 4 Levels ( <= 1yr, >1 yr - 2yrs ,  >2yrs , never ).
-Adjusted labels for the following variables to emphasize data is taken across all models:
	MM04count
	MM06count
	MM01ChanceGetCancer
	MM02RelativeChanceCancer  - Also edited format to emphasize data is taken across all models
	MM03FreqWorryCancer
	MM05aCannotLowerChance
	MM05bTooManyRecommendations
	MM05cCancerOverYears
	MM05dSlowDownCancer
	MM05eBehaviorCauseCancer
	MM05fEverythingCausesCancer
	MM05hCheckCancerAfraid
	MM05iCheckEarlyDetect
	MM05LPainPriorToDx
	MM07HowManySurvive


The following changes were made for the
February 27, 2006 release

-Removed Psa1yr (2-15-06).
-Removed Capitalization of Variables
-Added label to CancerType
-Edited label for End5Yr
-Edited labels for HHInc1 , HHInc2 (added word "Household Income").
-Changed format of Mam1Yr from Endf. to Mamf.
-Added format to DB01WhyChoseInternet DB05SpecifyDifficulties DB09Distractions
-Changed formats TUGRP1C and TUGRP2C

The following changes were made for the
March 02, 2006 release

-Replaced Weights with corrected values provided by Westat(sasdata/hints2wgt.sas7bdat)

The following changes were made for the
March 17, 2006 release

-Corrected formats to CA23eWhyNotContactedSource DB01WhyChoseInternet DB05SpecifyDifficulties DB09Distractions

The following changes were made for the
April 14, 2006 release

-Edited Formats TUGRP1C and TUGRP2C (Changed Text)
-Edited Format Division (Removed Format Value for 0, Pacific Division)
-Discarded Variable DB10WhereCompleted_OS (Had All Missing Values)
-Changed 0 Values of Division to 9
-Changed Missing Values of DMA to 18 for 3 Respondents with FIPS=08014
-Changed label of TUGrp1Cnt to "Number of new tobacco products tried from Group 1 (Eclipse, Quest, Marlboro Ultrasmooth, Accord, Advance, Omni)"
-Changed label of TUGrp2Cnt to "Number of new tobacco products tried from Group 2 (Ariva, Revel, Exalt, Stonewall)"
-Changed label of TUGrp1Used1 to "Tobacco product used from Group 1 (Eclipse, Quest, Marlboro Ultrasmooth, Accord, Advance, Omni)"
-Changed label of TUGrp1Used2 to "Tobacco product used from Group 1 (Eclipse, Quest, Marlboro Ultrasmooth, Accord, Advance, Omni)"
-Changed label of TUGrp2Used1 to "Tobacco product used from Group 2  (Ariva, Revel, Exalt, Stonewall)"
-Changed label of DM06BornInUSA to "-->DM-06. Were you born in the United States?"
-Changed label of HC02CWeekendInternet to "-->HC-02C. During a typical weekend, about how many hours do you use the Internet for personal reasons?"
-Changed Exault to Exalt in the labels of TU19jHowHeardExalt1-TU19jHowHeardExalt5 and TU19jHowHeardExalt_OS
-Changed label of TU20aTriedWhichProduct01 to -->TU20a. Which new product have you tried? (First Response)
-Changed label of TU20aTriedWhichProduct02 to -->TU20a. Which new product have you tried? (Second Response)
-Removed All Variable Recodes( AgeGrp, Educ4, Education5, RaceEthn, HHIncB, HHIncA, FruitJuice, Potatoes
							   Fruits, Vegetables, Pap3Yr, Mam1Yr, FOB1Yr, End5Yr, MM04Count, MM06Count,
							   MM01ChanceGetCancer, MM02RelativeChanceCancer, MM03FreqWorryCancer, MM05aCannotLowerChance
							   MM05bTooManyRecommendations, MM05cCancerOverYears, MM05dSlowDownCancer, MM05eBehaviorCauseCancer
							   MM05fEverythingCausesCancer, MM05hCheckCancerAfraid, MM05iCheckEarlyDetect, MM05LPainPriorToDx
							   MM07HowManySurvive, DistressScore, Distressed, BMI, AgeDX, TimeSinceDX, CancerType)

The following changes were made for the June 1, 2006 release:

- Added Variable Recodes with Ref/DK/NA Categories - ( AgeGrp, Educ4, Education5, RaceEthn, HHIncB, HHIncA, FruitJuice, Potatoes
							   						   Fruits, Vegetables, Pap3Yr, Mam1Yr, FOB1Yr, End5Yr, MM04Count, MM06Count,
							   						   MM07HowManySurvive, DistressScore, Distressed, BMI, AgeDX, TimeSinceDX, CancerType)
- Added Non-Geographic Variable Recodes (MM01ChanceGetCancer, MM02RelativeChanceCancer, MM03FreqWorryCancer, MM05aCannotLowerChance,
										 MM05bTooManyRecommendations, MM05cCancerOverYears, MM05dSlowDownCancer, MM05eBehaviorCauseCancer,
										 MM05fEverythingCausesCancer, MM05hCheckCancerAfraid, MM05iCheckEarlyDetect, MM05LpainPriorToDx,
										 MM07HowManySurvive)
- Removed formats PSA1Yr, Pap2Yr, TUGRP1C, TUGRP2C
- Removed variables TuGrp1Cnt TuGrp2Cnt BirthYear BackFromInternet
- Recodes Education4 Education5 renamed EducA EducB
- Recode AgeGrp rename to AgeGrpA, and new recode AgeGrpB added
- Adjusted labels for newly recoded variables
- Changed algorithm for BMI computation
- Edited labels for DMA, RUC2003, Division, Region, TUGrp1Used1, TUGrp1Used2, TUGrp2Used1
- Edited format of MM02RelativeChanceCancer and TimeSinceDX
- Renamed HHIncA --> HHIncC
- Added HHIncA coded similar to HINTS 2003 Version
- Added Recodes SelfProxy DaysSinceInfo TimeSinceInfo
- Changed Ref/DK/NA Values of HHIncB and Distressed from 97-98-99 to 7-8-9
- Renamed formats for Fruits Vegetables FruitJuice Potatoes from  TU04SMOK. --> RefDkNa.
- Renamed formats for TimeSinceDX TSDF. --> TimeDX.

*/

options nocenter ls=max;

%let datenum = 2006_06_02;
%let datetext = June 02 2006;

title1 "Program: /prj/brp/hints/data/2005/progs/create.hints2005.d&datenum..public.sas";
title2 "2005 HINTS Extended Data, &datetext Public Version";

***Input files;
libname raw "/prj/brp/hints/data/2005/sasdata/raw/";
libname geo "/prj/brp/hints/data/misc/";
filename FORMATS "/prj/brp/hints/data/2005/progs/formats.hints2005.d&datenum..public.sas";
filename CANCTYPE "/prj/brp/hints/moser/cancertype.01-04-2006.unformatted.csv";
filename FIPSDMA '/prj/brp/hints/data/misc/fips_dma.csv';
filename RURALURB '/prj/brp/hints/data/misc/RuralUrbanCodes2003.csv';

***Output files;
filename OUTFILE1 pipe "gzip -c > /prj/brp/hints/data/2005/sasdata/hints2005.d&datenum..public.v8x.gz";
filename CONTENTS "contents.hints2005.d&datenum..public.pdf";

proc format;
%include FORMATS;

data hints05(drop=i fwgt--fwgt50);
	set raw.hints_2005_extended_completes raw.hints_2005_extended_partials;

	array a_ca13[*] CA13WhatLookCancerInfo1-CA13WhatLookCancerInfo6;
	do i = 1 to dim(a_ca13);
	  if a_ca13[i]=22 then a_ca13[i]=23;
	end;

	if HS05FreqGoProvider=52 then HS05FreqGoProvider=6;

	label
	  GA2WhereUseInternet2   = "-->GA-2. Where do you go on-line from to use the Internet?"
	  MM05iCheckEarlyDetectC = "-->MM-05i. Getting checked regularly for colon cancer increases the chances of finding cancer when its easy to treat."
	  MM04ReduceCancerS_OS   = "-->MM-04. What are some things that people can do to reduce their chances of getting skin cancer? Specify:"
	  EB17ChangeBehaviorExer = "-->EB-17. Think about the last time you heard a new recommendation about physical activity or exercise. Which of the following things did you do in response to the new recommendation?"
	  TUGrp1Used1 			 = "-->TUGrp1Used1. Tobacco product used from Group 1 (Eclipse, Quest, Marlboro Ultrasmooth, Accord, Advance, Omni)"
	  TUGrp1Used2 			 = "-->TUGrp1Used2. Tobacco product used from Group 1 (Eclipse, Quest, Marlboro Ultrasmooth, Accord, Advance, Omni)"
	  TUGrp2Used1 			 = "-->TUGrp2Used1. Tobacco product used from Group 2  (Ariva, Revel, Exalt, Stonewall)"
	  DM06BornInUSA 		 = "-->DM-06. Were you born in the United States?"
	  HC02CWeekendInternet   = "-->HC-02C. During a typical weekend, about how many hours do you use the Internet for personal reasons?"
	  TU19jHowHeardExalt_OS  = "-->TU-19j. How did you hear about Exalt? Specify:"
	  TU20aTriedWhichProduct01 = "-->TU20a. Which new product have you tried? (First Response)"
	  TU20aTriedWhichProduct02 = "-->TU20a. Which new product have you tried? (Second Response)"
	  ;

	attrib TU19jHowHeardExalt1-TU19jHowHeardExalt5 label="-->TU-19j. How did you hear about Exalt?";

	***Recodes***;

	label AgeGrpA = '-->AgeGrpA. (SpAge-ImgAgeRange Recode - 4 Levels)';
	format AgeGrpA AgeGrpA.;
	if 		18<=SpAge<=34 or ImgAgeRange=2 then AgeGrpA=1;**18-34;
	else if 35<=SpAge<=39 or ImgAgeRange=3 then AgeGrpA=2;**35-39;
	else if 40<=SpAge<=44 or ImgAgeRange=4 then AgeGrpA=3;**40-45;
	else if 45<=SpAge<997 or ImgAgeRange=5 then AgeGrpA=4;**45+;
	else AgeGrpA=SpAge-990;

	label AgeGrpB = '-->AgeGrpB. (SpAge-ImgAgeRange Recode - 5 Levels)';
	format AgeGrpB AgeGrpB.;
	if 		18<=SpAge<=34 or ImgAgeRange=2 		  then AgeGrpB=1;**18-34;
	else if 35<=SpAge<=49 or ImgAgeRange in (3,4) then AgeGrpB=2;**35-49;
	else if 50<=SpAge<=64                         then AgeGrpB=3;**50-64;
	else if 65<=SpAge<=74                         then AgeGrpB=4;**65-74;
	else if 75<=SpAge<997                         then AgeGrpB=5;**75+;
	else if     SpAge=998 and ImgAgeRange in (5)  then AgeGrpB=8;**45+, exact age refused;
	else if     SpAge=999 and ImgAgeRange in (5)  then AgeGrpB=9;**45+, exact age unknown;
	else AgeGrpB=SpAge-900;

	label EducA = "-->EducA. What is the highest level of school you completed? (DM03 Recode - 4 Lvls)";
	select (DM03Education);
		when (1,2,3,4)						EducA=1;*<HS;
		when (5)							EducA=2;*=HS;
		when (6,7,8)						EducA=3;*<CG;
		when (9,10,11)						EducA=4;*>=CG;
		otherwise							EducA=DM03Education-90;
		end;
	format EducA educaf.;

	label EducB = "-->EducB. What is the highest level of school you completed? (DM03 Recode - 5 Lvls)";
	select (DM03Education);
		when (1,2,3,4)						EducB=1;*<HS;
		when (5)							EducB=2;*=HS;
		when (6,7,8)						EducB=3;*<CG;
		when (9)							EducB=4;*=CG;
		when (10,11)						EducB=5;*>CG;
		otherwise							EducB=DM03Education-90;
		end;
	format EducB educbf.;

	label RaceEthn = '-->Race/Ethnicity. (DM04-DM05 Recode)';
	if 	  DM04Hispanic=1 				then RaceEthn=1;**hispanic;
	else if DM04Hispanic=2 then do;
		if 11 le DM05Race2 le 15 or
		   11 le DM05Race3 le 15 or
		   11 le DM05Race4 le 15 or
		   11 le DM05Race5 le 15 			then RaceEthn=7;**NH other;
		else if DM05Race1=11 				then RaceEthn=2;**NH White;
		else if DM05Race1=12				then RaceEthn=3;**NH Black;
		else if DM05Race1=13				then RaceEthn=5;**NH Asian;
		else if DM05Race1=14				then RaceEthn=4;**NH AI/AN;
		else if DM05Race1=15				then RaceEthn=6;**NH NH/PI;
		else								RaceEthn=DM05Race1;
		end;
	else RaceEthn=DM04Hispanic+90;
	format RaceEthn RaceEthn.;

	array check[11] DM14jIncomeOver200Thousand DM14iIncomeOver100Thousand DM14hIncome100Thousand
					DM14gIncome75Thousand DM14fIncome50Thousand DM14eIncome35Thousand
					DM14dIncome10Thousand DM14cIncome15Thousand DM14bIncome20Thousand
					DM14aIncome25Thousand DM14Income
					;
	label HHIncB = '-->HHIncB. What is your {combined} annual household income? (DM14 Recode - 5 Lvls)';
	select;
		when (0     le DM14Income lt 25000)		HHIncB=1;*less than $25,000;
		when (25000 le DM14Income lt 35000)     HHIncB=2;*$25,000 to less than $35,000;
		when (35000 le DM14Income lt 50000)     HHIncB=3;*$35,000 to less than $50,000;
		when (50000 le DM14Income lt 75000)     HHIncB=4;*$50,000 to less than $75,000;
		when (75000 le DM14Income lt 99999997)  HHIncB=5;*$75,000 and over;
		otherwise do;***compensate for missing DM14Income Values***;
			if 		DM14aIncome25Thousand=1 then HHIncB=1;*less than $25,000;
			else if DM14bIncome20Thousand=1 then HHIncB=1;*less than $25,000;
			else if DM14cIncome15Thousand=1 then HHIncB=1;*less than $25,000;
			else if DM14dIncome10Thousand=1 then HHIncB=1;*less than $25,000;
			else if DM14eIncome35Thousand=1  and DM14aIncome25Thousand=2 then HHIncB=2;*$25,000 to less than $35,000;
			else if DM14fIncome50Thousand=1  and DM14eIncome35Thousand=2 then HHIncB=3;*$35,000 to less than $50,000;
			else if DM14gIncome75Thousand=1  and DM14fIncome50Thousand=2 then HHIncB=4;*$50,000 to less than $75,000;
			else if DM14hIncome100Thousand=1 and DM14gIncome75Thousand=2 then HHIncB=5;*$75,000 and over;
			else if DM14iIncomeOver100Thousand=1 then HHIncB=5;*$75,000 and over;
			else if DM14jIncomeOver200Thousand=1 then HHIncB=5;*$75,000 and over;
			else do i=1 to 10;
				if check[i] in (7,8,9) then do;
					HHIncB=check[i];
					leave;
					end;
				else if i=10 then HHIncB=DM14Income-99999990;
				end;
			end;
		end;
	format HHIncB HHIncB.;

	label HHIncC = '-->HHIncC. What is your {combined} annual household income? (DM14 Recode - 10 Lvls)';
	select;
		when (0      le DM14Income lt 10000)	HHIncC=1;*less than $10,000;
		when (10000  le DM14Income lt 15000)	HHIncC=2;*$10,000 to less than $15,000;
		when (15000  le DM14Income lt 20000)	HHIncC=3;*$15,000 to less than $20,000;
		when (20000  le DM14Income lt 25000)	HHIncC=4;*$20,000 to less than $25,000;
		when (25000  le DM14Income lt 35000)    HHIncC=5;*$25,000 to less than $35,000;
		when (35000  le DM14Income lt 50000)    HHIncC=6;*$35,000 to less than $50,000;
		when (50000  le DM14Income lt 75000)    HHIncC=7;*$50,000 to less than $75,000;
		when (75000  le DM14Income lt 100000)  	HHIncC=8;*$75,000 to less than $100,000;
		when (100000 le DM14Income lt 200000)  	HHIncC=9;*$100,000 to less than $200,000;
		when (200000 le DM14Income lt 99999997) HHIncC=10;*$200,000 and over;
		otherwise do;***compensate for missing DM14Income Values***;
			if 		DM14dIncome10Thousand=1 then HHIncC=1;*less than $10,000;
			else if DM14cIncome15Thousand=1 and DM14dIncome10Thousand=2 then HHIncC=2;*$10,000 to less than $15,000;
			else if DM14bIncome20Thousand=1 and DM14cIncome15Thousand=2 then HHIncC=3;*$15,000 to less than $20,000;
			else if DM14aIncome25Thousand=1 and DM14bIncome20Thousand=2 then HHIncC=4;*$20,000 to less than $25,000;
			else if DM14eIncome35Thousand=1 and DM14aIncome25Thousand=2 then HHIncC=5;*$25,000 to less than $35,000;
			else if DM14fIncome50Thousand=1 and DM14eIncome35Thousand=2 then HHIncC=6;*$35,000 to less than $50,000;
			else if DM14gIncome75Thousand=1 and DM14fIncome50Thousand=2 then HHIncC=7;*$50,000 to less than $75,000;
			else if DM14hIncome100Thousand=1 and DM14gIncome75Thousand=2 then HHIncC=8;*$75,000 to less than $100,000;
			else if DM14iIncomeover100Thousand=1 then HHIncC=9;*$100,000 to less than $200,000;
			else if DM14jIncomeover200Thousand=1 then HHIncC=10;*$200,000 and over;
			else do i=1 to 10;
				if check[i] in (7,8,9) then do;
					HHIncC=check[i]+90;
					leave;
					end;
				else if i=10 then HHIncC=DM14Income-99999900;
				end;
			end;
		end;
	format HHIncC HHIncC.;

	label HHIncA="-->HHIncA. What is your {combined} annual household income? (DM14 Recode - 8 Lvls)";
	if HHIncC in (9,10) then HHIncA=8;*$75,000 and over;
	else HHIncA=HHIncC;
	format HHIncA HHIncA.;

	label FruitJuice = '-->FruitJuice. How often do you drink fruit juice per day? (EB01 Recode)';
	if 1 le EB01FruitJuice le 94 then do;
		select (EB01FruitJuice_Unit);
			when (1) 	FruitJuice=EB01FruitJuice;
			when (2)	FruitJuice=EB01FruitJuice/7;
			when (3)	FruitJuice=EB01FruitJuice/30;
			when (4)	FruitJuice=EB01FruitJuice/365;
			otherwise   FruitJuice=EB01FruitJuice_Unit+90;
			end;
		end;
	else if EB01FruitJuice=95 then FruitJuice=0;
	else FruitJuice=EB01FruitJuice;
	format FruitJuice RefDkNa.;

	label Potatoes = '-->Potatoes. How often do you eat potatoes per day? (EB03 Recode)';
	if 1 le EB03Potatoes le 94 then do;
		select (EB03Potatoes_Unit);
			when (1) 	Potatoes=EB03Potatoes;
			when (2)	Potatoes=EB03Potatoes/7;
			when (3)	Potatoes=EB03Potatoes/30;
			when (4)	Potatoes=EB03Potatoes/365;
			otherwise	Potatoes=EB03Potatoes_Unit+90;
			end;
		end;
	else if EB03Potatoes=95 then Potatoes=0;
	else Potatoes=EB03Potatoes;
	format Potatoes RefDkNa.;

	label Fruits = '-->Fruits. How often do you eat fruit per day? (EB02 Recode)';
	if 1 le EB02Fruits le 94 then do;
		select (EB02Fruits_Unit);
			when (1) 	Fruits=EB02Fruits;
			when (2)	Fruits=EB02Fruits/7;
			when (3)	Fruits=EB02Fruits/30;
			when (4)	Fruits=EB02Fruits/365;
			otherwise	Fruits=EB02Fruits_Unit+90;
			end;
		end;
	else if EB02Fruits=95 then Fruits=0;
	else Fruits=EB02Fruits;
	format Fruits RefDkNa.;

	label Vegetables = '-->Vegetables. How often do you eat vegetables per day? (excl. potatoes)? (EB04 Recode)';
	if 1 le EB04Vegetables le 94 then do;
		select (EB04Vegetables_Unit);
			when (1) 	Vegetables=EB04Vegetables;
			when (2)	Vegetables=EB04Vegetables/7;
			when (3)	Vegetables=EB04Vegetables/30;
			when (4)	Vegetables=EB04Vegetables/365;
			otherwise	Vegetables=EB04Vegetables_Unit+90;
			end;
		end;
	else if EB04Vegetables=95 then Vegetables=0;
	else Vegetables=EB04Vegetables;
	format Vegetables RefDkNa.;

	%let lab = %str(Guidelines based on recommendations from the U.S. Preventive Services Task Force, 2005. <http://www.ahrq.gov/clinic/uspstfix.htm>);

	label Pap3Yr = "-->Pap3Yr. When was your last Pap Screen? &lab";
	if CV01HadPapSmear=1 then do;
		select(CV02WhenPapSmear);
			when(1,2)		Pap3Yr=1;**Had Pap Screen within last 3 yrs;
			when(3,4)		Pap3Yr=2;**Had Pap Screen more than 3 yrs ago;
			otherwise		Pap3Yr=CV02WhenPapSmear;
			end;
		end;
	else if CV01HadPapSmear=2 then Pap3Yr=3;**Never had Pap Screen;
	else Pap3Yr=CV01HadPapSmear;
	format Pap3Yr papf.;

	label Mam1Yr = "-->Mam1Yr. When was your last Mammogram? &lab";
	if BC01HadMammogram=1 then do;
		select(BC02WhenMammogram);
			when(1)			Mam1Yr=1;**Had Mammogram within last 1 yr;
			when(2)			Mam1Yr=2;**Had Mammogram >1 to 2 yrs ago;
			when(3,4) 		Mam1Yr=3;**Had Mammogram Over 2 yrs age;
			otherwise		Mam1Yr=BC02WhenMammogram;
			end;
		end;
	else if BC01HadMammogram=2 then Mam1Yr=4;**Never had Mammogram;
	else Mam1Yr=BC01HadMammogram;
	format Mam1Yr mamf.;

	label FOB1Yr = "-->FOB1Yr. When was your last Home Stool Blood Test? &lab";
	if CC05HadStoolBlood=1 then do;
		select(CC06WhenStoolBlood);
			when(1)			FOB1Yr=1;**Had FOBT within last 1 yr;
			when(2,3,4)		FOB1Yr=2;**Had FOBT more than 1 yr ago;
			otherwise		FOB1Yr=CC06WhenStoolBlood;
			end;
		end;
	else if CC05HadStoolBlood=2 then FOB1Yr=3;**Never had FOBT;
	else FOB1Yr=CC05HadStoolBlood;
	format FOB1Yr fobtf.;

	label End5Yr = "-->End5Yr. When was your last Endoscopy? &lab";
	if CC07HadSigCol=1 then do;
		select(CC08WhenSigCol);
			when(1,2)		End5Yr=1;**Had Endoscopy within last 1 yr;
			when(3,4)		End5Yr=2;**Had Endoscopy more than 1 yr ago;
			otherwise		End5Yr=CC08WhenSigCol;
			end;
		end;
	else if CC07HadSigCol=2 then End5Yr=3;**Never had Endoscopy;
	else End5Yr=CC07HadSigCol;
	format End5Yr endof.;

	***Psychological distress composite based on NHIS (see http://www.cdc.gov/nchs/data/nhis/earlyrelease/200309_13.pdf);
	***Modified from "Respondent Characteristics.sas" from Bradford Hesse 10/23/2003;
	label DistressScore = '-->DistressScore. Psychological Distress Composite Score 0-24 (HS02 Recode)';
	array a_stressed[6] HS02aSad HS02bNervous HS02cRestless HS02dHopeless HS02eEffort HS02fWorthless;
	DistressScore = 0;
	do i=1 to 6;
		if a_stressed[7-i] in (7,8,9) then do;
	  			DistressScore=a_stressed[7-i]+90;
	  			leave;
	  			end;
		else DistressScore = DistressScore + (5 - a_stressed[i]);
		end;
	format DistressScore RefDkNa.;

	label Distressed = '-->Distressed. Serious Psychological Distress (HS02 Recode)';
	format Distressed Distress.;
	if 0<=DistressScore<=12 then Distressed = 0; ***No;
	else if 13<=DistressScore<=24 then Distressed = 1; ***Yes;
	else if DistressScore in (97,98,99) then Distressed=DistressScore-90;

	***  Algorithm for BMI supplied by the Centers for Disease Control - Department of Health & Human Services  ***;
	***  See the following website --> http://www.cdc.gov/nccdphp/dnpa/bmi/adult_BMI/about_adult_BMI.htm        ***;

	if EB23Weight ge 997 then BMI=EB23Weight;
	else if EB22Height_Inches ge 97 then BMI=EB22Height_Inches+900;
	else if EB22Height_Feet ge 97 then BMI=EB22Height_Feet+900;
	else BMI=round(703*EB23Weight/((12*EB22Height_Feet + EB22Height_Inches)*(12*EB22Height_Feet + EB22Height_Inches)),.1);
	label BMI = '-->BMI. Body Mass Index (EB22-EB23 Recode)';
	format BMI SpAge.;

	label AgeDX = '-->AgeDX. At what age were you diagnosed with cancer? (CA03-SpAge-BirthYear Recode)';
	if CA01EverHadCancer ne 1 then AgeDX=.;
	else if SpAge in (997,998,999) then AgeDX=SpAge;
	else do;
		select(CA03WhenDiagnosedCancer_Unit);
			when (1)	AgeDX=CA03WhenDiagnosedCancer;
			when (2)	do;
				if birthyear NE .  then AgeDX=CA03WhenDiagnosedCancer-birthyear;
				else if 18 le spage le 96 then AgeDX=CA03WhenDiagnosedCancer-(2005-spage);
				end;
			otherwise AgeDx=CA03WhenDiagnosedCancer_Unit+990;
			end;
		end;
	format AgeDX SpAge.;

	label TimeSinceDX = '-->TimeSinceDX. How long ago were you diagnosed with cancer? (CA03-SpAge-BirthYear Recode)';
	if CA01EverHadCancer ne 1 then AgeDX=.;
	else if SpAge in (997,998,999) then TimeSinceDX=SpAge-990;
	else if CA03WhenDiagnosedCancer_Unit in (7,8,9) then TimeSinceDX=CA03WhenDiagnosedCancer_Unit;
	else if	0 le spage-AgeDX le 1 	then TimeSinceDX=1;*<=1;
	else if 2 le spage-AgeDX le 5 	then TimeSinceDX=2;*2-5 yrs;
	else if 6 le spage-AgeDX le 10 	then TimeSinceDX=3;*6-10 yrs;
	else if      spage-AgeDX gt 10 	then TimeSinceDX=4;*11+ yrs;
	else;
	format TimeSinceDX timedx.;

	label DaysSinceInfo = '-->DaysSinceInfo. How many days since you looked for cancer info? (CA11 Recode)';
	select(CA11LookCancerInfo_Unit);
		when(1)		DaysSinceInfo=CA11LookCancerInfo;
		when(2)		DaysSinceInfo=CA11LookCancerInfo*7;
		when(3)		DaysSinceInfo=CA11LookCancerInfo*30;
		when(4)		DaysSinceInfo=round(CA11LookCancerInfo*365.25);
		otherwise   DaysSinceInfo=CA11LookCancerInfo_Unit+99990;
		end;
	format DaysSinceInfo DaysSinc.;

	***Code for TimeSinceInfo was supplied by Richard Moser 02/18/2005;
	label TimeSinceInfo = '-->TimeSinceInfo. How long ago did you seek cancer info? (CA11 Recode)';
	select(CA11LookCancerInfo_Unit);
		when(1) timeseekinfo=CA11LookCancerInfo;
		when(2) timeseekinfo=CA11LookCancerInfo*7;
		when(3) timeseekinfo=CA11LookCancerInfo*30.5;
		when(4) timeseekinfo=CA11LookCancerInfo*365;
		otherwise;
		end;
	timeseekinfomonths=(timeseekinfo/30.5);
	TimeSinceInfo=1*(0<timeseekinfomonths<=1) + 2*(1<timeseekinfomonths<=6) + 3*(6<timeseekinfomonths<=12)
	+ 4*(12<timeseekinfomonths<=60) + 5*(60<timeseekinfomonths<500);
	if TimeSinceInfo=0 then TimeSinceInfo=CA11LookCancerInfo_Unit;
	drop timeseekinfo timeseekinfomonths;
	format TimeSinceInfo timesinc.;

	***Code for SelfProxy was suppplied by Richard Moser 02/15/2005;
	label SelfProxy = '--> SelfProxy. Did you look for information by yourself, by proxy, both or neither? (CA08-CA09 Recode)';
	format selfproxy selfprox.;
	if CA08SeekCancerInfo=1 and CA09OtherSeekCancerInfo=1 then selfproxy=1;
	else if CA08SeekCancerInfo=1 and CA09OtherSeekCancerInfo=2 then selfproxy=2;
	else if CA08SeekCancerInfo=2 and CA09OtherSeekCancerInfo=1 then selfproxy=3;
	else if CA08SeekCancerInfo=2 and CA09OtherSeekCancerInfo=2 then selfproxy=4;
	else if CA08SeekCancerInfo in (7,8,9) then selfproxy=CA08SeekCancerInfo;
	else if CA09OtherSeekCancerInfo in (7,8,9) then selfproxy=CA09OtherSeekCancerInfo;

	***Recodes of MM-04: What are some things that people can do to reduce their risk of cancer?;
	array lung[6] MM04ReduceCancerL01-MM04ReduceCancerL06;
	array colon[8] MM04ReduceCancerC01-MM04ReduceCancerC08;
	array skin[6] MM04ReduceCancerS01-MM04ReduceCancerS06;

	label MM04Count = '-->MM04Count. How many things can people do to reduce their chances of getting colon/lung/skin cancer? (MM04 Recode)';
	MM04Count=0;
	select(MMGrp);
		when (1) do i=1 to 8;
				if colon[i] ne . and colon[i] not in (97,98,99) then MM04Count=MM04Count+1;
				else if i=1 then do;
					MM04Count=colon[1];
					leave;
					end;
				end;
		when (2) do i=1 to 6;
				if lung[i] ne . and lung[i] not in (97,98,99) then MM04Count=MM04Count+1;
				else if i=1 then do;
					MM04Count=lung[1];
					leave;
					end;
				end;
		when (3) do i=1 to 6;
				if skin[i] ne . and skin[i] not in (97,98,99) then MM04Count=MM04Count+1;
				else if i=1 then do;
					MM04Count=skin[1];
					leave;
					end;
				end;
		otherwise;
		end;
	format MM04Count RefDkNa.;

	***Recodes of MM-06: What are the common symptoms cancer?;
	array lung2[7] MM06SymptomsOfCancerL01-MM06SymptomsOfCancerL07;
	array colon2[9] MM06SymptomsOfCancerC01-MM06SymptomsOfCancerC09;
	array skin2[6] MM06SymptomsOfCancerS01-MM06SymptomsOfCancerS06;

	label MM06Count = '-->MM06Count. How many common symptoms of colon/lung/skin cancer are there? (MM06 Recode)';
	MM06Count=0;**initialize;
	select(MMGrp);
		when (1) do i=1 to 9;
				if colon2[i] ne . and colon2[i] not in (97,98,99) then MM06Count=MM06Count+1;
				else if i=1 then do;
					MM06Count=colon2[1];
					leave;
					end;
				end;
		when (2) do i=1 to 7;
				if lung2[i] ne . and lung2[i] not in (97,98,99) then MM06Count=MM06Count+1;
				else if i=1 then do;
					MM06Count=lung2[1];
					leave;
					end;
				end;
		when (3) do i=1 to 6;
				if skin2[i] ne . and skin2[i] not in (97,98,99) then MM06Count=MM06Count+1;
				else if i=1 then do;
					MM06Count=skin2[1];
					leave;
					end;
				end;
		otherwise;
		end;
	format MM06Count RefDkNa.;

	***collapse mental models variables over entire survey***;
	select(MMGrp);
		when (1) do;
			MM01ChanceGetCancer=MM01ChanceGetCancerC;
			MM02RelativeChanceCancer=MM02RelativeChanceCancerC;
			MM03FreqWorryCancer=MM03FreqWorryCancerC;
			MM05aCannotLowerChance=MM05aCannotLowerChanceC;
			MM05bTooManyRecommendations=MM05bTooManyRecommendationsC;
			MM05cCancerOverYears=MM05cCancerOverYearsC;
			MM05dSlowDownCancer=MM05dSlowDownCancerC;
			MM05eBehaviorCauseCancer=MM05eBehaviorCauseCancerC;
			MM05fEverythingCausesCancer=MM05fEverythingCausesCancerC;
			MM05hCheckCancerAfraid=MM05hCheckCancerAfraidC;
			MM05iCheckEarlyDetect=MM05iCheckEarlyDetectC;
			MM05LPainPriorToDx=MM05LPainPriorToDxC;
			MM07HowManySurvive=MM07HowManySurviveC;
			end;
		when (2) do;
			MM01ChanceGetCancer=MM01ChanceGetCancerL;
			MM02RelativeChanceCancer=MM02RelativeChanceCancerL;
			MM03FreqWorryCancer=MM03FreqWorryCancerL;
			MM05aCannotLowerChance=MM05aCannotLowerChanceL;
			MM05bTooManyRecommendations=MM05bTooManyRecommendationsL;
			MM05cCancerOverYears=MM05cCancerOverYearsL;
			MM05dSlowDownCancer=MM05dSlowDownCancerL;
			MM05eBehaviorCauseCancer=MM05eBehaviorCauseCancerL;
			MM05fEverythingCausesCancer=MM05fEverythingCausesCancerL;
			MM05hCheckCancerAfraid=MM05hCheckCancerAfraidL;
			MM05iCheckEarlyDetect=MM05iCheckEarlyDetectL;
			MM05LPainPriorToDx=MM05LPainPriorToDxL;
			MM07HowManySurvive=MM07HowManySurviveL;
			end;
		when (3) do;
			MM01ChanceGetCancer=MM01ChanceGetCancerS;
			MM02RelativeChanceCancer=MM02RelativeChanceCancerS;
			MM03FreqWorryCancer=MM03FreqWorryCancerS;
			MM05aCannotLowerChance=MM05aCannotLowerChanceS;
			MM05bTooManyRecommendations=MM05bTooManyRecommendationsS;
			MM05cCancerOverYears=MM05cCancerOverYearsS;
			MM05dSlowDownCancer=MM05dSlowDownCancerS;
			MM05eBehaviorCauseCancer=MM05eBehaviorCauseCancerS;
			MM05fEverythingCausesCancer=MM05fEverythingCausesCancerS;
			MM05hCheckCancerAfraid=MM05hCheckCancerAfraidS;
			MM05iCheckEarlyDetect=MM05iCheckEarlyDetectS;
			MM05LPainPriorToDx=MM05LPainPriorToDxS;
			MM07HowManySurvive=MM07HowManySurviveS;
			end;
		otherwise;
		end;

	%let cls = colon/lung/skin;

label
MM01ChanceGetCancer="-->MM-01-recode. How likely do you think it is that you will develop &cls cancer in the future?"
MM02RelativeChanceCancer="-->MM-02-recode. Compared to the average person your age, would you say that for &cls cancer you are:"
MM03FreqWorryCancer="-->MM-03-recode. How often do you worry about getting &cls cancer?"
MM05aCannotLowerChance="-->MM-05a-recode. Theres not much you can do to lower your chances of getting &cls cancer."
MM05bTooManyRecommendations="-->MM-05b-recode. There are so many different recommendations about preventing &cls cancer that its hard to know which ones to follow."
MM05cCancerOverYears="-->MM-05c-recode. Colon/Lung/Skin cancer develops over a period of several years."
MM05dSlowDownCancer="-->MM-05d-recode. There are ways to slow down or disrupt the development of &cls cancer."
MM05eBehaviorCauseCancer="-->MM-05e-recode. Colon/Lung/Skin cancer is most often caused by a persons behavior or lifestyle."
MM05fEverythingCausesCancer="-->MM-05f-recode. It seems like almost everything causes &cls cancer."
MM05hCheckCancerAfraid="-->MM-05h-recode. You are reluctant to get checked for &cls cancer because you fear you may have it."
MM05iCheckEarlyDetect="-->MM-05i-recode. Getting checked regularly for &cls cancer increases the chances of finding cancer when its easy to treat."
MM05LPainPriorToDx="-->MM-05L-recode. People with colon/skin/lung cancer would have pain or other symptoms prior to being diagnosed."
MM07HowManySurvive="-->MM-07-recode. Overall, how many people who develop &cls cancer do you think survive at least 5 years?"
;
	run;

**********************************************************************************;
***Quality Control Review of New Variables****************************************;

**********************************************************************************;
***Add CancType variable.  This variable was devised by Michael Osswald.   It     ;
***recodes CH2TypeOfSPsCancer01-CH2TypeOfSPsCancer04 and CH2TypeOfSPsCancer_OS    ;
***into a single variable.                                                        ;
**********************************************************************************;
data cancer;
	infile canctype dsd firstobs=4;
	length CA02TypeofSPsCancer_OS $35;
	input CancerType CA01EverHadCancer CA02TypeofSPsCancer01 CA02TypeofSPsCancer02
			CA02TypeofSPsCancer03 CA02TypeofSPsCancer04 CA02TypeofSPsCancer05
			CA02TypeofSPsCancer_OS $ spgender;
	run;

%let CTVars = spgender CA01EverHadCancer CA02TypeofSPsCancer01 CA02TypeofSPsCancer02
			  CA02TypeofSPsCancer03 CA02TypeofSPsCancer04 CA02TypeofSPsCancer05
			  CA02TypeofSPsCancer_OS
			  ;
proc sort data=hints05; by &CTVars; run;
proc sort data=cancer; by &CTVars; run;

data hints05;
	merge hints05(in=p) cancer;
	by &CTVars;
	if p;
	label CancerType = "-->CancerType. Cancer Classification (CA01-CA02 Recode)";
	if CA02TypeofSPsCancer01 in (97,98,99) then Cancertype=CA02TypeofSPsCancer01;
	else if CancerType=13 then CancerType=99;**Not Known --> Don't Know**;
	format CancerType CANCTYPE.;
	run;

***Add Geographic Variables: GEO Data Set Provided by Rick Moser 12/28/05***;
data geographic;
	set geo.hints_2005_extended_geographic;
	run;

proc sort data=geographic; by caseno; run;
proc sort data=hints05; by caseno; run;

data hints05;
	merge hints05(in=p) geographic;
	by caseno;
	if p;
	label division="-->Division. Census Division"
		  region="-->Region. Census Region"
		  ;
	if division='0' then division='9';
	format Region region. Division divisio.;
	run;

***Add Designated Market Area***;
data fipsdma(keep=fips dma);
	infile FIPSDMA dsd firstobs=2;
	input fips: $char5. county $ state $ DMA;
	label DMA = '-->DMA. Designated Market Area';
	format DMA DMA.;
	run;

proc sort data=hints05; by fips; run;
proc sort data=fipsdma; by fips; run;

data hints05;
	merge hints05(in=p) fipsdma;
	by fips;
	if p;
	label fips="-->FIPS. 5-Digit FIPS Code";
	if fips='08014' and dma=. then dma=18;
	run;

***Add Rural Urban Continuum Codes***;
data ruralurb(keep=FIPS RUC2003);
	infile RURALURB dsd firstobs=2;
	input
	  FIPS: $char5.
	  State: $char2.
	  CountyName: $char50.
	  RUC1993
	  RUC2003
	  Pop2000: comma10.
	  PctComm
	  Desc2003: $char100.
	  ;
	label RUC2003 = '-->RUC2003. 2003 Rural-Urban Continuum Code (county-level, from Economic Research Service / USDA)'
		  State="-->State. State Abbreviation"
		  ;
	format RUC2003 RUC2003f.;
	run;

proc sort data=ruralurb; by FIPS;
proc sort data=hints05; by FIPS; run;

data hints05;
	merge hints05(in=p) ruralurb;
	by FIPS;
	if p;
	run;

***Add Corrected Weight Values***;
data newWeights;
	set raw.hints2wgt;
	run;

proc sort data=newWeights; by caseno; run;
proc sort data=hints05; by caseno; run;

data hints05;
	merge hints05(in=p) newWeights(in=q);
	by caseno;
	if p=0 or q=0 then abort;
	run;

***Formatting***;
data hints05;
	set hints05;

  	format
      EXTRSLT                          $EXTRSLT.
      SOURCE                            $SOURCE.
      INTERVIEWMETHOD                  INTERVIE.
      SPANENG                          $SPANENG.
      MODGRP                             MODGRP.
      HCGRP                               HCGRP.
      MMGRP                               MMGRP.
      NEGRP                               NEGRP.
      DBGRP                               DBGRP.
      INCGRP                             INCGRP.
      SPAGE                               SPAGE.
      SPGENDER                         SPGENDER.
      GA1USEINTERNET                   GA1USEIN.
      GA2WHEREUSEINTERNET1             GA2WHERE.
      GA2WHEREUSEINTERNET2             GA2WHERE.
      GA2WHEREUSEINTERNET3             GA2WHERE.
      GA2WHEREUSEINTERNET4             GA2WHERE.
      GA2WHEREUSEINTERNET5             GA2WHERE.
      GA3WHEREUSEINTERNETMOST          GA3WHERE.
      GA4AACCESSINTERNET               GA4AACCE.
      GA4BACCESSINTERNET               GA4BACCE.
      GA5MODECHOICE                    GA5MODEC.
      HC01AWATCHTV                     HC01AWAT.
      HC01BLISTENRADIO                 HC01AWAT.
      HC01CUSEINTERNET                 HC01AWAT.
      HC02AWEEKENDWATCHTV              HC02AWEE.
      HC02BWEEKENDRADIO                HC02AWEE.
      HC02CWEEKENDINTERNET             HC02AWEE.
      HC03AREADNEWSPAPER               HC03AREA.
      HC03BNATIONALNEWS                HC03AREA.
      HC03CLOCALNEWS                   HC03AREA.
      HC04READHEALTHSECTION            GA1USEIN.
      HC05HOWOFTENHEALTHSECTION        HC05HOWO.
      HC08HEALTHONNEWS                 GA1USEIN.
      HC09HOWOFTENHEALTHONNEWS         HC05HOWO.
      HC10NOTICEINFO                   GA1USEIN.
      HC11HOWOFTENNOTICEINFO           HC11HOWO.
      HC13ATRUSTDOCTOR                 HC13ATRU.
      HC13BTRUSTFAMILY                 HC13ATRU.
      HC13CTRUSTNEWSPAPER              HC13ATRU.
      HC13DTRUSTMAGAZINES              HC13ATRU.
      HC13ETRUSTRADIO                  HC13ATRU.
      HC13FTRUSTINTERNET               HC13ATRU.
      HC13GTRUSTTV                     HC13ATRU.
      HC14AHEALTHINFOSELF              GA1USEIN.
      HC14BHEALTHINFOOTHER             GA1USEIN.
      HC14CBUYMEDICINE                 GA1USEIN.
      HC14DSUPPORTGROUP                GA1USEIN.
      HC14ETALKDOCTOR                  GA1USEIN.
      HC14FEXERCISEINFO                GA1USEIN.
      HC14GDIETINFO                    GA1USEIN.
      HC14HSUNINFO                     GA1USEIN.
      HC14ISMOKINGINFO                 GA1USEIN.
      HC14KANYTHINGELSEONLINE          GA1USEIN.
      HC15TALKEDDOCTOR                 GA1USEIN.
      HC16DOCTORINTERESTED             HC16DOCT.
      CA01EVERHADCANCER                CA01EVER.
      CA02TYPEOFSPSCANCER01            CA02TYPE.
      CA02TYPEOFSPSCANCER02            CA02TYPE.
      CA02TYPEOFSPSCANCER03            CA02TYPE.
      CA02TYPEOFSPSCANCER04            CA02TYPE.
      CA02TYPEOFSPSCANCER05            CA02TYPE.
      CA03WHENDIAGNOSEDCANCER_UNIT     CA03WHEF.
      CA04UNDERGOCANCERTREATMENT       GA1USEIN.
      CA05HOWLONGFINISHTREATMENT_UNIT  CA05HOWF.
      CA06FAMILYEVERHADCANCER          CA06FAMI.
      CA07TYPEFAMILYCANCER01           CA02TYPE.
      CA07TYPEFAMILYCANCER02           CA02TYPE.
      CA07TYPEFAMILYCANCER03           CA02TYPE.
      CA07TYPEFAMILYCANCER04           CA02TYPE.
      CA07TYPEFAMILYCANCER05           CA02TYPE.
      CA07TYPEFAMILYCANCER06           CA02TYPE.
      CA07TYPEFAMILYCANCER07           CA02TYPE.
      CA07TYPEFAMILYCANCER08           CA02TYPE.
      CA08SEEKCANCERINFO               GA1USEIN.
      CA09OTHERSEEKCANCERINFO          GA1USEIN.
      CA10WHOSEEKCANCERINFO1           CA10WHOS.
      CA10WHOSEEKCANCERINFO2           CA10WHOS.
      CA10WHOSEEKCANCERINFO3           CA10WHOS.
      CA10WHOSEEKCANCERINFO4           CA10WHOS.
      CA11LOOKCANCERINFO_UNIT          CA11LOOF.
      CA12WHERELOOKCANCERINFO          CA12WHER.
      CA13WHATLOOKCANCERINFO1          CA13WHAT.
      CA13WHATLOOKCANCERINFO2          CA13WHAT.
      CA13WHATLOOKCANCERINFO3          CA13WHAT.
      CA13WHATLOOKCANCERINFO4          CA13WHAT.
      CA13WHATLOOKCANCERINFO5          CA13WHAT.
      CA13WHATLOOKCANCERINFO6          CA13WHAT.
      CA14AALOTEFFORT                  CA14AALO.
      CA14BFRUSTRATED                  CA14AALO.
      CA14CCONCERNEDQUALITY            CA14AALO.
      CA14DTOOHARDUNDERSTAND           CA14AALO.
      CA15INTERNETFORCANCER            GA1USEIN.
      CA16USEFULINTERNETFORCANCER      CA16USEF.
      CA17CONFIDENTGETCANCERINFO       CA17CONF.
      CA18WHEREGOFIRST                 CA18WHER.
      CA21CNCI                         GA1USEIN.
      CA21DCIS                         GA1USEIN.
      CA21ECANCERHOTLINE               GA1USEIN.
      CA21HACS800NUMBER                GA1USEIN.
      CA21ICANCERCONTROL               GA1USEIN.
      CA22DCONTACTEDSOURCE             GA1USEIN.
      CA22ECONTACTEDSOURCE             GA1USEIN.
      CA23EWHYNOTCONTACTEDSOURCE	   CA23F.
      PC01EVERHEARDPSATEST             GA1USEIN.
      PC02HADPSATEST                   PC02HADP.
      PC03WHENPSATEST                  PC03WHEN.
      PC04PROVIDERTALKEDPSA            GA1USEIN.
      PC05PROVIDERRECOMMENDPSA         PC05PROV.
      PC06QUESTIONSABOUTPSA            PC06QUES.
      CV01HADPAPSMEAR                  GA1USEIN.
      CV02WHENPAPSMEAR                 CV02WHEN.
      CV03WHYPAPSMEAR                  CV03WHYP.
      CV04PAPSMEARBEFORELAST           CV04PAPS.
      CV05HYSTERECTOMY                 GA1USEIN.
      CV06WHENNEXTPAPSMEAR             CV06WHEN.
      CV07HOWOFTENPAPSMEAR             CV07HOWO.
      CV08GUIDELINESCHANGE             GA1USEIN.
      CV09LESSFREQUENTPAPSMEAR         GA1USEIN.
      CV10TREATEDWARTS                 GA1USEIN.
      CV11HEARDHPV                     GA1USEIN.
      CV12EVERHADHPV                   GA1USEIN.
      CV13AHPVCAUSECANCER              GA1USEIN.
      CV13BHPVSTD                      GA1USEIN.
      CV13CHPVRARE                     GA1USEIN.
      CV13DHPVGOAWAY                   GA1USEIN.
      CV13EHPVCAUSEABNORMALPAP         GA1USEIN.
      CV13FHPVAFFECTPREGNANCY          GA1USEIN.
      BC01HADMAMMOGRAM                 GA1USEIN.
      BC02WHENMAMMOGRAM                BC02WHEN.
      CC01TESTSFORCOLONCANCER1         CC01TEST.
      CC01TESTSFORCOLONCANCER2         CC01TEST.
      CC01TESTSFORCOLONCANCER3         CC01TEST.
      CC01TESTSFORCOLONCANCER4         CC01TEST.
      CC01TESTSFORCOLONCANCER5         CC01TEST.
      CC01TESTSFORCOLONCANCER6         CC01TEST.
      CC01TESTSFORCOLONCANCER7         CC01TEST.
      CC04ADVISECHECKCOLONCANCER       GA1USEIN.
      CC05HADSTOOLBLOOD                GA1USEIN.
      CC06WHENSTOOLBLOOD               BC02WHEN.
      CC07HADSIGCOL                    GA1USEIN.
      CC08WHENSIGCOL                   CC08WHEN.
      MM01CHANCEGETCANCERC             MM01CHAN.
      MM02RELATIVECHANCECANCERC        MM02RELA.
      MM03FREQWORRYCANCERC             MM03FREQ.
      MM04REDUCECANCERC01              MM04REDF.
      MM04REDUCECANCERC02              MM04REDF.
      MM04REDUCECANCERC03              MM04REDF.
      MM04REDUCECANCERC04              MM04REDF.
      MM04REDUCECANCERC05              MM04REDF.
      MM04REDUCECANCERC06              MM04REDF.
      MM04REDUCECANCERC07              MM04REDF.
      MM04REDUCECANCERC08              MM04REDF.
      MM05ACANNOTLOWERCHANCEC          MM05ACAN.
      MM05BTOOMANYRECOMMENDATIONSC     MM05ACAN.
      MM05CCANCEROVERYEARSC            MM05ACAN.
      MM05DSLOWDOWNCANCERC             MM05ACAN.
      MM05EBEHAVIORCAUSECANCERC        MM05ACAN.
      MM05FEVERYTHINGCAUSESCANCERC     MM05ACAN.
      MM05HCHECKCANCERAFRAIDC          MM05ACAN.
      MM05ICHECKEARLYDETECTC           MM05ACAN.
      MM05LPainPriorToDxC              MM05ACAN.
      MM06SYMPTOMSOFCANCERC01          MM06SYMF.
      MM06SYMPTOMSOFCANCERC02          MM06SYMF.
      MM06SYMPTOMSOFCANCERC03          MM06SYMF.
      MM06SYMPTOMSOFCANCERC04          MM06SYMF.
      MM06SYMPTOMSOFCANCERC05          MM06SYMF.
      MM06SYMPTOMSOFCANCERC06          MM06SYMF.
      MM06SYMPTOMSOFCANCERC07          MM06SYMF.
      MM06SYMPTOMSOFCANCERC08          MM06SYMF.
      MM06SYMPTOMSOFCANCERC09          MM06SYMF.
      MM07HOWMANYSURVIVEC              MM07HOWM.
      SP01ASUNSCREEN                   SP01ASUN.
      SP01BSHADE                       SP01BSHA.
      SP01CHAT                         SP01BSHA.
      SP01DLONGSLEEVESHIRT             SP01BSHA.
      SP01ELONGPANTS                   SP01BSHA.
      SP02TANNINGDEVICES               SP02TANN.
      SP03TANNINGPRODUCTS              SP02TANN.
      MM01CHANCEGETCANCERS             MM01CHAN.
      MM02RELATIVECHANCECANCERS        MM02RELG.
      MM03FREQWORRYCANCERS             MM03FREQ.
      MM04REDUCECANCERS01              MM04REDG.
      MM04REDUCECANCERS02              MM04REDG.
      MM04REDUCECANCERS03              MM04REDG.
      MM04REDUCECANCERS04              MM04REDG.
      MM04REDUCECANCERS05              MM04REDG.
      MM04REDUCECANCERS06              MM04REDG.
      MM05ACANNOTLOWERCHANCES          MM05ACAN.
      MM05BTOOMANYRECOMMENDATIONSS     MM05ACAN.
      MM05CCANCEROVERYEARSS            MM05ACAN.
      MM05DSLOWDOWNCANCERS             MM05ACAN.
      MM05EBEHAVIORCAUSECANCERS        MM05ACAN.
      MM05FEVERYTHINGCAUSESCANCERS     MM05ACAN.
      MM05HCHECKCANCERAFRAIDS          MM05ACAN.
      MM05ICHECKEARLYDETECTS           MM05ACAN.
      MM05LPainPriorToDxS              MM05ACAN.
      MM06SYMPTOMSOFCANCERS01          MM06SYMG.
      MM06SYMPTOMSOFCANCERS02          MM06SYMG.
      MM06SYMPTOMSOFCANCERS03          MM06SYMG.
      MM06SYMPTOMSOFCANCERS04          MM06SYMG.
      MM06SYMPTOMSOFCANCERS05          MM06SYMG.
      MM06SYMPTOMSOFCANCERS06          MM06SYMG.
      MM07HOWMANYSURVIVES              MM07HOWM.
      TU01SMOKE100                     GA1USEIN.
      TU02SMOKENOW                     TU02SMOK.
      TU03SMOKEDAYALWAYS               TU03SMOK.
      TU04SMOKEPAST30DAYS              TU04SMOK.
      TU05SMOKEDAYSOMETIMES            TU03SMOK.
      TU06TRIEDQUIT                    GA1USEIN.
      TU07STOPPEDSMOKETRYQUIT          GA1USEIN.
      TU08TIMESSTOPPEDSMOKE            TU08TIME.
      TU10CONSIDERQUIT                 GA1USEIN.
      TU11WHENQUITSMOKE                TU11WHEN.
      TU11WHENQUITSMOKE_UNIT           TU11WHEF.
      TU12SMOKEEVERYDAY6MONTHS         GA1USEIN.
      TU13SMOKEDAYFORMER               TU03SMOK.
      TU14HOWOFTENFORMERSMOKER         TU02SMOK.
      TU17WOULDTRYLESSHARMFULCIG       TU17WOUL.
      TU18AHEARDECLIPSE                GA1USEIN.
      TU19AHOWHEARDECLIPSE1            TU19AHOW.
      TU19AHOWHEARDECLIPSE2            TU19AHOW.
      TU19AHOWHEARDECLIPSE3            TU19AHOW.
      TU19AHOWHEARDECLIPSE4            TU19AHOW.
      TU18BHEARDQUEST                  GA1USEIN.
      TU19BHOWHEARDQUEST1              TU19AHOW.
      TU19BHOWHEARDQUEST2              TU19AHOW.
      TU19BHOWHEARDQUEST3              TU19AHOW.
      TU19BHOWHEARDQUEST4              TU19AHOW.
      TU18CHEARDMARLBORO               GA1USEIN.
      TU19CHOWHEARDMARLBORO1           TU19AHOW.
      TU19CHOWHEARDMARLBORO2           TU19AHOW.
      TU19CHOWHEARDMARLBORO3           TU19AHOW.
      TU19CHOWHEARDMARLBORO4           TU19AHOW.
      TU18DHEARDARIVA                  GA1USEIN.
      TU19DHOWHEARDARIVA1              TU19AHOW.
      TU19DHOWHEARDARIVA2              TU19AHOW.
      TU19DHOWHEARDARIVA3              TU19AHOW.
      TU19DHOWHEARDARIVA4              TU19AHOW.
      TU18EHEARDREVEL                  GA1USEIN.
      TU19EHOWHEARDREVEL1              TU19AHOW.
      TU19EHOWHEARDREVEL2              TU19AHOW.
      TU19EHOWHEARDREVEL3              TU19AHOW.
      TU19EHOWHEARDREVEL4              TU19AHOW.
      TU19EHOWHEARDREVEL5              TU19AHOW.
      TU18JIWHETHERHEARDOTHER          GA1USEIN.
      TU18JIIHEARDOTHERPRODUCT1        TU18JIIH.
      TU18JIIHEARDOTHERPRODUCT2        TU18JIIH.
      TU18JIIHEARDOTHERPRODUCT3        TU18JIIH.
      TU18JIIHEARDOTHERPRODUCT4        TU18JIIH.
      TU18JIIHEARDOTHERPRODUCT5        TU18JIIH.
      TU19JHOWHEARDACCORD1             TU19AHOW.
      TU19JHOWHEARDACCORD2             TU19AHOW.
      TU19JHOWHEARDACCORD3             TU19AHOW.
      TU19JHOWHEARDACCORD4             TU19AHOW.
      TU19JHOWHEARDACCORD5             TU19AHOW.
      TU19JHOWHEARDADVANCE1            TU19AHOW.
      TU19JHOWHEARDADVANCE2            TU19AHOW.
      TU19JHOWHEARDADVANCE3            TU19AHOW.
      TU19JHOWHEARDADVANCE4            TU19AHOW.
      TU19JHOWHEARDADVANCE5            TU19AHOW.
      TU19JHOWHEARDOMNI1               TU19AHOW.
      TU19JHOWHEARDOMNI2               TU19AHOW.
      TU19JHOWHEARDOMNI3               TU19AHOW.
      TU19JHOWHEARDOMNI4               TU19AHOW.
      TU19JHOWHEARDOMNI5               TU19AHOW.
      TU19JHOWHEARDEXALT1              TU19AHOW.
      TU19JHOWHEARDEXALT2              TU19AHOW.
      TU19JHOWHEARDEXALT3              TU19AHOW.
      TU19JHOWHEARDEXALT4              TU19AHOW.
      TU19JHOWHEARDEXALT5              TU19AHOW.
      TU19JHOWHEARDSTONEWALL1          TU19AHOW.
      TU19JHOWHEARDSTONEWALL2          TU19AHOW.
      TU19JHOWHEARDSTONEWALL3          TU19AHOW.
      TU19JHOWHEARDOTHER1              TU19AHOW.
      TU19JHOWHEARDOTHER2              TU19AHOW.
      TU20TRIEDNEWPRODUCT              GA1USEIN.
      TU20ATRIEDWHICHPRODUCT01         TU20ATRI.
      TU20ATRIEDWHICHPRODUCT02         TU20ATRI.
      TU21NOWUSENEWPRODUCTGRP1         TU21NOWU.
      TU22HOWOFTENNEWPRODUCTGRP1       TU22HOWO.
      TU23WHYUSENEWPRODUCTGRP1         TU23WHYU.
      TU24HOWHARMFULNEWPRODUCTGRP1     TU24HOWH.
      TU21NOWUSENEWPRODUCTGRP2         TU21NOWU.
      TU22HOWOFTENNEWPRODUCTGRP2       TU22HOWO.
      TU23WHYUSENEWPRODUCTGRP2         TU23WHYU.
      TU24HOWHARMFULNEWPRODUCTGRP2     TU24HOWH.
      MM01CHANCEGETCANCERL             MM01CHAN.
      MM02RELATIVECHANCECANCERL        MM02RELF.
      MM03FREQWORRYCANCERL             MM03FREQ.
      MM04REDUCECANCERL01              MM04REDU.
      MM04REDUCECANCERL02              MM04REDU.
      MM04REDUCECANCERL03              MM04REDU.
      MM04REDUCECANCERL04              MM04REDU.
      MM04REDUCECANCERL05              MM04REDU.
      MM04REDUCECANCERL06              MM04REDU.
      MM05ACANNOTLOWERCHANCEL          MM05ACAN.
      MM05BTOOMANYRECOMMENDATIONSL     MM05ACAN.
      MM05CCANCEROVERYEARSL            MM05ACAN.
      MM05DSLOWDOWNCANCERL             MM05ACAN.
      MM05EBEHAVIORCAUSECANCERL        MM05ACAN.
      MM05FEVERYTHINGCAUSESCANCERL     MM05ACAN.
      MM05HCHECKCANCERAFRAIDL          MM05ACAN.
      MM05ICHECKEARLYDETECTL           MM05ACAN.
      MM05LPainPriorToDxL              MM05ACAN.
      MM06SYMPTOMSOFCANCERL01          MM06SYMP.
      MM06SYMPTOMSOFCANCERL02          MM06SYMP.
      MM06SYMPTOMSOFCANCERL03          MM06SYMP.
      MM06SYMPTOMSOFCANCERL04          MM06SYMP.
      MM06SYMPTOMSOFCANCERL05          MM06SYMP.
      MM06SYMPTOMSOFCANCERL06          MM06SYMP.
      MM06SYMPTOMSOFCANCERL07          MM06SYMP.
      MM07HOWMANYSURVIVEL              MM07HOWM.
      MM01CHANCEGETCANCER              MM01CHAN.
      MM02RELATIVECHANCECANCER         MM02REL.
      MM03FREQWORRYCANCER              MM03FREQ.
      MM05ACANNOTLOWERCHANCE           MM05ACAN.
      MM05BTOOMANYRECOMMENDATIONS      MM05ACAN.
      MM05CCANCEROVERYEARS             MM05ACAN.
      MM05DSLOWDOWNCANCER              MM05ACAN.
      MM05EBEHAVIORCAUSECANCER         MM05ACAN.
      MM05FEVERYTHINGCAUSESCANCER      MM05ACAN.
      MM05HCHECKCANCERAFRAID           MM05ACAN.
      MM05ICHECKEARLYDETECT            MM05ACAN.
      MM05LPainPriorToDx               MM05ACAN.
      MM07HOWMANYSURVIVE               MM07HOWM.
      EB01FRUITJUICE                   EB01FRUI.
      EB01FRUITJUICE_UNIT              EB01FRUF.
      EB02FRUITS                       EB01FRUI.
      EB02FRUITS_UNIT                  EB01FRUF.
      EB03POTATOES                     EB01FRUI.
      EB03POTATOES_UNIT                EB01FRUF.
      EB04VEGETABLES                   EB01FRUI.
      EB04VEGETABLES_UNIT              EB01FRUF.
      EB05NUMBERSERVINGS               EB05NUMB.
      EB06TIMESMODERATEEXERCISE        EB06TIME.
      EB07HOWLONGMODERATEEXERCISE      EB07HOWL.
      EB07HOWLONGMODERATEEXERCISE_UNIT EB07HOW.
      EB08RECOMMENDDAYSEXERCISE        EB08RECO.
      EB09RECOMMENDTIMEEXERCISE        EB07HOWL.
      EB09RECOMMENDTIMEEXERCISE_UNIT   EB09RECO.
      EB10EXERCISELOWERRISKCANCER      EB10EXER.
      EB11LOSTWEIGHT                   GA1USEIN.
      EB12AWARELOWCARB                 GA1USEIN.
      EB13TRIEDLOWCARB                 GA1USEIN.
      EB15LOWCARBDIETHEALTHY           GA1USEIN.
      EB16PAYATTENTIONDIET             EB16PAYA.
      EB17CHANGEBEHAVIORDIET           EB17CHAN.
      EB18TOOMANYRECOMMENDDIET         CA14AALO.
      EB20HEARDDIET                    GA1USEIN.
      EB21ATVDIET                      HC13ATRU.
      EB21BNEWSPAPERDIET               HC13ATRU.
      EB21CMAGAZINEDIET                HC13ATRU.
      EB21DINTERNETDIET                HC13ATRU.
      EB21EDOCTORDIET                  HC13ATRU.
      EB16PAYATTENTIONEXER             EB16PAYA.
      EB17CHANGEBEHAVIOREXER           EB17CHAN.
      EB18TOOMANYRECOMMENDEXER         CA14AALO.
      EB19LOSE30MINUTES                CA14AALO.
      EB20HEARDEXER                    GA1USEIN.
      EB21ATVEXER                      HC13ATRU.
      EB21BNEWSPAPEREXER               HC13ATRU.
      EB21CMAGAZINEEXER                HC13ATRU.
      EB21DINTERNETEXER                HC13ATRU.
      EB21EDOCTOREXER                  HC13ATRU.
      EB22HEIGHT_FEET                  EB22HEIF.
      EB22HEIGHT_INCHES                EB22HEIG.
      EB23WEIGHT                       EB23WEIG.
      HS01GENERALHEALTH                HS01GENE.
      HS02ASAD                         HS02ASAD.
      HS02BNERVOUS                     HS02ASAD.
      HS02CRESTLESS                    HS02ASAD.
      HS02DHOPELESS                    HS02ASAD.
      HS02EEFFORT                      HS02ASAD.
      HS02FWORTHLESS                   HS02ASAD.
      HS03DEPRESSIONINTERFERE          HC13ATRU.
      HS04HEALTHINSURANCE              GA1USEIN.
      HS05FREQGOPROVIDER               HS05FREQ.
      SN01COMMUNITYORGS                SN01COMM.
      SN02COMMORGSHEALTHINFO           GA1USEIN.
      SN03TALKHEALTHFRIENDS            GA1USEIN.
      SN04FREQTALKHEALTHFRIENDS        SN04FREQ.
      SN05RIDETOPROVIDER               SN01COMM.
      SN06RELIGIOUSSERVICES            SN06RELI.
      DM01MAINACTIVITY                 DM01MAIN.
      DM02MARITALSTATUS                DM02MARI.
      DM03EDUCATION                    DM03EDUC.
      DM04HISPANIC                     GA1USEIN.
      DM05RACE1                        DM05RACE.
      DM05RACE2                        DM05RACE.
      DM05RACE3                        DM05RACE.
      DM05RACE4                        DM05RACE.
      DM05RACE5                        DM05RACE.
      DM06BORNINUSA                    GA1USEIN.
      DM07YEARCAMETOUSA                DM07YEAR.
      DM08COMFORTWITHENGLISH           DM08COMF.
      DM09RENTOROWN                    DM09RENT.
      DM11NUMBERINHH                   DM11NUMB.
      DM12NUMBERINHHRELATED            DM12NUMB.
      DM13NUMBERUNDER18                DM12NUMB.
      DM14INCOME                       DM14INCO.
      DM14AINCOME25THOUSAND            GA1USEIN.
      DM14BINCOME20THOUSAND            GA1USEIN.
      DM14CINCOME15THOUSAND            GA1USEIN.
      DM14dIncome10Thousand            GA1USEIN.
      DM14EINCOME35THOUSAND            GA1USEIN.
      DM14fIncome50Thousand            GA1USEIN.
      DM14GINCOME75THOUSAND            GA1USEIN.
      DM14hIncome100Thousand           GA1USEIN.
      DM14IINCOMEOVER100THOUSAND       GA1USEIN.
      DM14JINCOMEOVER200THOUSAND       GA1USEIN.
      DM15MONEYSETASIDE                DM15MONE.
      DB01WhyChoseInternet			   CA23F.
      DB02RECEIVEDEMAIL                GA1USEIN.
      DB03RECEIVEDLETTER               GA1USEIN.
      DB04ACCESSDIFFICULTIES           GA1USEIN.
      DB05SpecifyDifficulties		   CA23F.
      DB06HOWSATISFIEDWITHSPEED        DB06HOWS.
      DB07TOOKBREAK                    DB07TOOK.
      DB08WHETHERDISTRACTED            GA1USEIN.
      DB09Distractions                 CA23F.
      DB10WHERECOMPLETED               DB10WHER.
      DB11WHYCHOSETELEPHONE1           DB11WHYC.
      DB11WHYCHOSETELEPHONE2           DB11WHYC.
      DB11WHYCHOSETELEPHONE3           DB11WHYC.
      DB13RECEIVEDEMAIL                GA1USEIN.
      DB14RECEIVEDLETTER               GA1USEIN.
      DB15LENGTHOFSURVEY               DB15LENG.
      DB16INFLUENCEOFINCENTIVE         DB16INFL.
      ;
run;

***************************************************************************************************;
***Quality Control;
%macro summarize(classlist);
	proc summary nway missing data=hints05;
    	class &classlist;
    	output out=summ;
  		run;

	proc print data=summ(drop=_TYPE_) obs="Obs" style(data)=[just=right] label;
 		title3 "Reviewing Variable Recodes";
  		run;
	title3;
%mend;

%summarize(AgeGrpA SpAge ImgAgeRange);
%summarize(AgeGrpB SpAge ImgAgeRange);
%summarize(EducA DM03Education);
%summarize(EducB DM03Education);
%summarize(RaceEthn DM04Hispanic DM05Race1 DM05Race2 DM05Race3 DM05Race4 DM05Race5);
%summarize(	HHIncB DM14Income DM14dIncome10Thousand DM14cIncome15Thousand DM14bIncome20Thousand DM14aIncome25Thousand
			       DM14eIncome35Thousand DM14fIncome50Thousand DM14gIncome75Thousand DM14hIncome100Thousand
			       DM14iIncomeOver100Thousand DM14jIncomeOver200Thousand);
%summarize(	HHIncC DM14Income DM14dIncome10Thousand DM14cIncome15Thousand DM14bIncome20Thousand DM14aIncome25Thousand
			       DM14eIncome35Thousand DM14fIncome50Thousand DM14gIncome75Thousand DM14hIncome100Thousand
			       DM14iIncomeOver100Thousand DM14jIncomeOver200Thousand);
%summarize( HHIncA HHIncC);
%summarize( FruitJuice EB01FruitJuice_Unit EB01FruitJuice );
%summarize( Fruits     EB02Fruits_Unit     EB02Fruits );
%summarize( Potatoes   EB03Potatoes_Unit   EB03Potatoes );
%summarize( Vegetables EB04Vegetables_Unit EB04Vegetables );
%summarize( Pap3Yr	   CV01HadPapSmear     CV02WhenPapSmear);
%summarize( Mam1Yr	   BC01HadMammogram    BC02WhenMammogram);
%summarize( FOB1Yr	   CC05HadStoolBlood   CC06WhenStoolBlood);
%summarize( End5Yr	   CC07HadSigCol       CC08WhenSigCol);
%summarize( DistressScore HS02aSad HS02bNervous HS02cRestless HS02dHopeless HS02eEffort HS02fWorthless);
%summarize( Distressed DistressScore );
%summarize( BMI EB22Height_Feet EB22Height_Inches EB23Weight );
%summarize( AgeDX CA01EverHadCancer CA03WhenDiagnosedCancer_Unit CA03WhenDiagnosedCancer BirthYear SpAge );
%summarize( TimeSinceDX AgeDx CA01EverHadCancer CA03WhenDiagnosedCancer_Unit CA03WhenDiagnosedCancer BirthYear SpAge );
%summarize( DaysSinceInfo CA11LookCancerInfo_Unit CA11LookCancerInfo );
%summarize( TimeSinceInfo CA11LookCancerInfo_Unit CA11LookCancerInfo );
%summarize( SelfProxy CA08SeekCancerInfo CA09OtherSeekCancerInfo );
%summarize( CancerType SpGender CA01EverHadCancer CA02TypeofSPsCancer01-CA02TypeofSPsCancer05 CA02TypeofSPsCancer_OS);

***************************************************************************************************;
***Exporting Data Set;
data hints05;
	set hints05;
	drop DB10WhereCompleted_OS TUGRP1CNT TUGRP2CNT
		 State FIPS CI1HHZIPCODE CI1HHSTATE GA7HHSTATE GA7HHZIPCODE
	     BACKFROMINTERNET BIRTHYEAR GA0LANGUAGE IMGAGERANGE
	     ;
	run;

proc freq data=hints05(drop=caseno fwgt fwgt1-fwgt50);
  tables _all_ / missing;
run;

options nocenter orientation=landscape;
ods pdf file=CONTENTS;
proc contents data=hints05;
run;
ods pdf close;

proc cport data=hints05 file=OUTFILE1;
run;